<?php

/**
 * Filtriramo proizvode po TecDoc kategoriji.
 *
 * Ako radimo query za kategoriju proizvoda, a ta kategorija je ustvari TecDoc
 * kategorija, prvo tražimo iz TecDoc-a artikle za tu kategoriju i odabrano vozilo.
 *
 * Query u principu pokušava prikazati samo one proizvode koje smo dobili iz TecDoc-a.
 *
 * @param WP_Query $query
 */
function ep_tecdoc_product_cat_query(WP_Query $query) {
	if ( ! $query->is_main_query()) {
		return;
	}

	$category = get_queried_object();

	if (!$category instanceof WP_Term || $category->taxonomy !== 'product_cat') {
		return;
	}

	if ($genericArticleIds = get_term_meta($category->term_id, 'genericArticleIds', true)) {
		$genericArticleIds = array_filter(array_map('absint', explode(';', $genericArticleIds)));

		$tecdoc   = ep_tecdoc_service();
		$articles = $tecdoc->getArticlesByGenericIds($genericArticleIds);

		$articleKeys = array_map(function ($article) {
			return $article['key'];
		}, $articles);

		if (count($articles) > 0) {
			$query->set('product_cat', '');
			$query->set('meta_query', [
				[
					'key'     => '_tecDoc_key',
					'value'   => $articleKeys,
					'compare' => 'IN',
				],
			]);
		} else {
			$query->set('ID', 0);
		}
	}
}

/**
 * @param WP_Post[] $posts
 * @param WP_Query $query
 *
 * @return array
 */
function ep_tecdoc_product_get_posts(array $posts, WP_Query $query)
{
	if (property_exists($query, 'tecdocArticles') && is_array($query->tecdocArticles)) {
		foreach ($posts as $post) {
			$key = get_post_meta($post->ID, '_tecDoc_key', true);

			foreach ($query->tecdocArticles as $article) {
				if ($key === $article['key']) {
					$post->tecdocArticle = $article;
					break;
				}
			}
		}
	}

	return $posts;
}